<?php

/**
 * @file
 * Handling class for Kewego API.
 */

class KewegoConnection {

  public $appKey = '';
  public $appToken = '';
  public $authToken = '';
  public $username = '';
  public $password = '';

  //Class constructor
  function __construct() {

    $this->appKey = variable_get('media_kewego_ApiKey', '');
    $this->username = variable_get('media_kewego_username', '');
    $this->password = variable_get('media_kewego_password', '');
    $this->player_key = variable_get('media_kewego_playerKey', '');

    /**
     *Checking and Getting appToken.
     */

    if (isset($_SESSION['appToken'])) {
      // there is a session variable
      $this->appToken = $_SESSION['appToken'];

      // Checking previous appToken validity.

      if ($this->check_app_token() === FALSE) {
        // AppToken is expired.
        if ($this->appToken = $this->getAppToken()) {
          // New appToken stored in session.
          $_SESSION['appToken'] = $this->appToken;
        }
        else {
          watchdog('Kewego Connection', 'Unable to get appToken', array(), WATCHDOG_INFO);
        }
      }
    }

    else {
      // There is no session variable.
      if ($this->appToken = $this->getAppToken()) {
        // New appToken stored in session.
        $_SESSION['appToken'] = $this->appToken;
      }
        else {
        watchdog('Kewego Connection', 'Unable to get appToken', array(), WATCHDOG_INFO);
      }
    }

    /**
     *Checking and Getting authToken.
     */

    if (isset($_SESSION['authToken'])) {
      // There is a session variable.
      $this->authToken = $_SESSION['authToken'];

      if ($this->check_auth_token() === FALSE) {
        if ($this->authToken = $this->getAuthToken()) {
          // New authToken stored in session.
          $_SESSION['authToken'] = $this->getAuthToken();
        }
      }
    }
    else {
      // There is no session variable.
      if ($this->authToken = $this->getAuthToken()) {
        // New authToken stored in session.
        $_SESSION['authToken'] = $this->authToken;
      }
      else {
        watchdog('Kewego Connection', 'Unable to get authToken', array(), WATCHDOG_INFO);
      }
    }

  }
  
  // Main Call function using http_request.
  function Call($api_url, $data_array, $post = TRUE) {

    $query = drupal_http_build_query($data_array);

    $options = array(
      'headers' => array('Content-Type' => 'application/x-www-form-urlencoded'),
      'data' => $query,
      'timeout' => 100,
    );

    if ($post === TRUE) $options['method'] = 'POST';

    $return = drupal_http_request($api_url, $options);

    if (isset($return->error)) $error = $return->error;

    if (!empty($error)) {
      watchdog('Kewego API', $error, array(), WATCHDOG_INFO);
    }
    return $return->data;
  }

  function getAppToken() {
    $response = $this->Call('http://api.kewego.com/app/getToken/', array('appKey' => $this->appKey));
    $xml_message = simplexml_load_string($response);
    $appToken = $xml_message->message->appToken;
    return (string)$appToken;
  }

  function check_app_token() {
    $response = $this->Call('http://api.kewego.com/app/checkToken/', array('appToken' => $this->appToken));
    $xml_message = simplexml_load_string($response);
    $validity = $xml_message->message->appToken;

    if ($validity == TRUE) {
      return TRUE;
    }
    return FALSE;
  }

  function getAuthToken() {
    $response = $this->Call('http://login.kewego.com/api/getLoginToken/', array(
      'username' => $this->username,
      'password' => $this->password,
      'appToken' => $this->appToken
    ));
    $xml_message = simplexml_load_string($response);
    $authToken = $xml_message->message->token;
    return (string)$authToken;
  }

  function check_auth_token() {
    $response = $this->Call('http://api.kewego.com/auth/checkToken/', array('token' => $this->authToken, 'appToken' => $this->appToken));
    $xml_message = simplexml_load_string($response);
    $validity = $xml_message->message->check_token;
    if ( "TRUE" == $validity) {
      return TRUE;
    }
    return FALSE;
  }
  
  function getAvailableCategories() {
    $response = trim($this->Call('http://api.kewego.com/upload/getAvailableCategories/', array('appToken' => $this->appToken)));
    $xml_message = simplexml_load_string($response, 'SimpleXMLElement', LIBXML_NOCDATA);
    $xml_categories = $xml_message->message->categories->category;
    $categories = array();
    foreach ($xml_categories as $category) {
      $categories[] = (string)$category;
    }
    return $categories;
  }

  function getVideosDetail($sig) {
    $response = trim($this->Call('http://api.kewego.com/video/getDetails/', array( 'sig' => $sig, 'appToken' => $this->appToken)));
    $xml_message = simplexml_load_string($response, 'SimpleXMLElement', LIBXML_NOCDATA);
    $Video_details = $xml_message->message;
    return $Video_details;
  }

  function getVideosList($start = 0, $limit = 5) {

    $response = trim($this->Call('http://api.kewego.com/user/getVideos/', array(
      'username' => $this->username,
      'appToken' => $this->appToken,
      'start' => $start,
      'max_result_per_page' => $limit,
      'format_thumb' => 'small'
    )));

    $xml_message = simplexml_load_string($response, 'SimpleXMLElement', LIBXML_NOCDATA);
    $Video_list = $xml_message->message;
    return $Video_list;
  }

  function getVideosThumbnail($sig = NULL, $number = '1', $size = 'large') {
    $response = trim($this->Call('http://api.kewego.com/video/getThumbnailsURL/', array(
      'sig' => $sig,
      'appToken' => $this->appToken,
      'number' => $number,
      'size' => $size
    )));
    
    $xml_message = simplexml_load_string($response, 'SimpleXMLElement', LIBXML_NOCDATA);
    $Video_Thumbnail = $xml_message->message->thumbnails->image;
    return $Video_Thumbnail;
  }

  function getPlayerCode($sig = NULL, $autostart = TRUE, $width = NULL, $height = NULL, $language_code = 'fr', $version = 'kp', $playerKey = 'default') {
    if ($playerKey ==  'default') $playerKey = $this->player_key;
    $response = trim($this->Call('http://api.kewego.com/video/getPlayerCode/', array( 'sig' => $sig, 'appToken' => $this->appToken, 'config_key' => $playerKey, 'autostart' => $autostart, 'width' => $width, 'height' => $height, 'language_code' => $language_code, 'version' => $version)));
    $xml_message = simplexml_load_string($response, 'SimpleXMLElement', LIBXML_NOCDATA);
    $Player_code = $xml_message->message->blog;
    return $Player_code;
  }
  
  function getStream($sig = NULL) {
    $response = trim($this->Call('http://api.kewego.com/video/getStreamURL/', array( 'sig' => $sig, 'appToken' => $this->appToken, 'playerKey' => $this->player_key, 'downloadable' => 'yes', 'format' => 'normal')));
    $xml_message = simplexml_load_string($response, 'SimpleXMLElement', LIBXML_NOCDATA);
    $Stream = $xml_message->message->videoStream;
    return $Stream;
  }
  
  function getSourceFileURL($sig) {
    $appToken = $this->appToken;
    $authToken = $this->authToken;
    $url = "http://api.kewego.com/video/getSourceFile/?sig=$sig&appToken=$appToken&token=$authToken";
    return $url;
  }

  // Upload a video.
  function upload_video($file) {
    $sig = $file->filename;
    $filepath = drupal_realpath($file->uri);
    $progressID = md5_file($filepath);
    $url = 'http://upload.kewego.com/api/uploadVideo/index.php?X-Progress-ID=' . $progressID;

    $apptoken = $this->appToken;
    $authtoken = $this->authToken;

    $xml_data = $this->generateXMLDetails($file);

    watchdog('Kewego', 'File: %file, Url: %url, XML generated for upload : %xml', array('%file' => $file->filename, '%url' => $url, '%xml' => $xml_data), WATCHDOG_INFO);

    $data = array(
      'file' => '@' . $filepath,
      'xml_data' => $xml_data,
      'token' => $authtoken,
      'appToken' => $apptoken
    );

    $ch  = curl_init($url);

    // Setting curl options and datas for upload.
    curl_setopt($ch, CURLOPT_HEADER, FALSE);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_POST, TRUE);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array('Expect:'));

    if (($response = curl_exec($ch)) === FALSE) {
      watchdog('Kewego', 'Erreur Curl : ' . curl_error($ch), array(), WATCHDOG_INFO);
      return FALSE;
    }
    else {
      $parsed_response = simplexml_load_string($response);
      $new_sig = $parsed_response->message->sig;
      watchdog('Kewego', 'Video has been correctly sent to API. API returned : <br/>' . $response . '<br/>' . $new_sig, array(), WATCHDOG_INFO);
      return $new_sig;
    }

    curl_close($ch);
  }

  function generateXMLDetails($file) {

    if (isset($file->media_title[LANGUAGE_NONE])) {
      $file_title =  check_plain($file->media_title[LANGUAGE_NONE][0]['value']);
    }
    else {
      $file_title =  check_plain($file->filename);
    }

    if (isset($file->media_description[LANGUAGE_NONE][0]['value'])) {
      $file_description =  $file->media_description[LANGUAGE_NONE][0]['value'];
    }
    else {
      $file_description =  'default description';
    }

    // Display all keywords.
    $keywords = '';

    if (isset($file->field_tags[LANGUAGE_NONE]) && count($file->field_tags[LANGUAGE_NONE])) {
      foreach ($file->field_tags[LANGUAGE_NONE] as $tid) {
        $term = taxonomy_term_load($tid['tid']);
        $keywords .= '<keyword>' . $term->name . '</keyword>';
      }
    }
    else {
      $keywords .= '<keyword>Kewego</keyword><keyword>API</keyword>';
    }

    $xml_data = "<kewego_call>
                    <params>
                        <title>$file_title</title>
                        <description>$file_description</description>
                        <categories>
                          <category>Aviation</category>
                        </categories>
                        <keywords>
                          $keywords
                        </keywords>
                        <language>fr</language>
                        <country>fr</country>
                        <postal_code>13000</postal_code>
                        <access>public</access>
                        <commentable>no</commentable>
                        <shareable>no</shareable>
                        <notable>no</notable>
                        <production_date>2011-01-01 12:00:00</production_date>
                    </params>
              </kewego_call>";
    return $xml_data;
  }

  function getUploadProgress($file) {
    $filepath = drupal_realpath($file->uri);
    $progressID = md5_file($filepath);
    $response = trim($this->Call('http://api.kewego.com/upload/getUploadProgress/', array( 'upload_key' => $progressID, 'appToken' => $this->appToken)));
    $xml_message = simplexml_load_string($response, 'SimpleXMLElement', LIBXML_NOCDATA);
    $state = $xml_message->message->state;
    $received = $xml_message->message->received;
    $size = $xml_message->message->size;
    $progress = array('state' => $state, 'received' => $received, 'size' => $size);
    return $progress;
  }

}
