<?php

/**
 * @file
 * Styles definitions for Media: kewego.
 */

/**
 * Implementation of Styles module hook_styles_register().
 */
function media_kewego_styles_register() {
  return array(
    'MediaKewegoStyles' => array(
      'field_types' => 'file',
      'name' => t('MediaKewego'),
      'description' => t('Media Kewego styles.'),
      'path' => drupal_get_path('module', 'media_kewego') . '/includes',
      'file' => 'media_kewego.styles.inc',
    ),
  );
}

/**
 * Implements hook_styles_containers(). (Deprecated in version 2)
 */
function media_kewego_styles_containers() {
  return array(
    'file' => array(
      'containers' => array(
        'media_kewego' => array(
          'label' => t('Kewego Styles'),
          'data' => array(
            'streams' => array(
              'kewego',
            ),
            'mimetypes' => array(
              'video/kewego',
            ),
          ),
          'weight' => 0,
          'filter callback' => 'media_kewego_formatter_filter',
          'themes' => array(
            'field_formatter_styles' => 'media_kewego_field_formatter_styles',
            'styles' => 'media_kewego_styles',
            'preview' => 'media_kewego_preview_style',
          ),
          'description' => t('Kewego Styles will display embedded Kewego videos and thumbnails to your choosing, such as by resizing, setting colors, and autoplay. You can !manage.', array('!manage' => l(t('manage your Kewego styles here'), 'admin/config/media/media-kewego-styles'))),
        ),
      ),
    ),
  );
}

function media_kewego_formatter_filter($variables) {
  if (isset($variables['object'])) {
    $object = $variables['object'];
    return (file_uri_scheme($object->uri) == 'kewego') && ($object->filemime == 'video/kewego');
  }
}

/**
 * Implementation of the File Styles module's hook_file_styles_filter().
 */
function media_kewego_file_styles_filter($object) {
  if ((file_uri_scheme($object->uri) == 'kewego') && ($object->filemime == 'video/kewego')) {
    return 'media_kewego';
  }
  else {
    if ((module_exists('media_derivatives')) && (isset($object->media_derivatives['derivatives_list']['kewego_video']))) return 'media_kewego';
  }
}

/**
 * Implements hook_styles_styles().
 */
function media_kewego_styles_styles() {
  $styles = array(
    'file' => array(
      'containers' => array(
        'media_kewego' => array(
          'styles' => array(
            'kewego_thumbnail' => array(
              'name' => 'kewego_thumbnail',
              'effects' => array(
                array('label' => t('Thumbnail'), 'name' => 'thumbnail', 'data' => array('thumbnail' => 1)),
                array('label' => t('Resize'), 'name' => 'resize', 'data' => array('width' => 100, 'height' => 75)),
              ),
            ),
            'kewego_preview' => array(
              'name' => 'kewego_preview',
              'effects' => array(
                array('label' => t('Autoplay'), 'name' => 'autoplay', 'data' => array('autoplay' => 1)),
                array('label' => t('Resize'), 'name' => 'resize', 'data' => array('width' => 220, 'height' => 165)),
              ),
            ),
            'kewego_full' => array(
              'name' => 'kewego_full',
              'effects' => array(
                array('label' => t('Autoplay'), 'name' => 'autoplay', 'data' => array('autoplay' => 0)),
                array('label' => t('Resize'), 'name' => 'resize', 'data' => array('width' => 640, 'height' => 480)),
                array('label' => t('Full screen'), 'name' => 'fullscreen', 'data' => array('fullscreen' => 1)),
              ),
            ),
          ),
        ),
      ),
    ),
  );

  // Allow any image style to be applied to the thumbnail.
  foreach (image_styles() as $style_name => $image_style) {
    $styles['file']['containers']['media_kewego']['styles']['kewego_thumbnail_' . $style_name] = array(
      'name' => 'kewego_thumbnail_' . $style_name,
      'image_style' => $style_name,
      'effects' => array(
        array('label' => t('Thumbnail'), 'name' => 'thumbnail', 'data' => array('thumbnail' => 1)),
      ),
    );
  }

  return $styles;
}

/**
 * Implements hook_styles_presets().
 */
function media_kewego_styles_presets() {
  $presets = array(
    'file' => array(
      'square_thumbnail' => array(
        'media_kewego' => array(
          'kewego_thumbnail_square_thumbnail',
        ),
      ),
      'thumbnail' => array(
        'media_kewego' => array(
          'kewego_thumbnail',
        ),
      ),
      'small' => array(
        'media_kewego' => array(
          'kewego_preview',
        ),
      ),
      'large' => array(
        'media_kewego' => array(
          'kewego_full',
        ),
      ),
      'original' => array(
        'media_kewego' => array(
          'kewego_full',
        ),
      ),
    ),
  );
  return $presets;
}

/**
 * Implementation of Styles module hook_styles_default_containers().
 */
function media_kewego_styles_default_containers() {
  // We append kewego to the file containers.
  return array(
    'file' => array(
      'containers' => array(
        'media_kewego' => array(
          'class' => 'MediaKewegoStyles',
          'name' => 'media_kewego',
          'label' => t('Kewego'),
          'preview' => 'media_kewego_preview_style',
        ),
      ),
    ),
  );
}


/**
 * Implementation of Styles module hook_styles_default_presets().
 */
function media_kewego_styles_default_presets() {
  $presets = array(
    'file' => array(
      'containers' => array(
        'media_kewego' => array(
          'default preset' => 'unlinked_thumbnail',
          'styles' => array(
            'original' => array(
              'default preset' => 'video',
            ),
            'thumbnail' => array(
              'default preset' => 'linked_thumbnail',
            ),
            'square_thumbnail' => array(
              'default preset' => 'linked_square_thumbnail',
            ),
            'medium' => array(
              'default preset' => 'linked_medium',
            ),
            'large' => array(
              'default preset' => 'large_video',
            ),
          ),
          'presets' => array(
            'video' => array(
              array(
                'name' => 'video',
                'settings' => array(),
              ),
            ),
            'large_video' => array(
              array(
                'name' => 'resize',
                'settings' => array(
                  'width' => 640,
                  'height' => 390,
                ),
              ),
              array(
                'name' => 'video',
                'settings' => array(),
              ),
            ),
          ),
        ),
      ),
    ),
  );
  // Allow any image style to be applied to the thumbnail.
  foreach (image_styles() as $style_name => $image_style) {
    $presets['file']['containers']['media_kewego']['presets']['linked_' . $style_name] = array(
      array(
        'name' => 'linkToMedia',
        'settings' => array(),
      ),
      array(
        'name' => 'imageStyle',
        'settings' => array(
          'image_style' => $style_name,
        ),
      ),
      array(
        'name' => 'thumbnail',
        'settings' => array(),
      ),
    );
    $presets['file']['containers']['media_kewego']['presets']['unlinked_' . $style_name] = $presets['file']['containers']['media_kewego']['presets']['linked_' . $style_name];
    array_shift($presets['file']['containers']['media_kewego']['presets']['unlinked_' . $style_name]);
  }
  return $presets;
}
