<?php

/**
 * @file
 * Theme and preprocess functions for Media: kewego.
 */

/**
 * Preprocess function for theme('media_kewego_video').
 */
function media_kewego_preprocess_media_kewego_video(&$variables) {
  // Build the URL for display.
  $uri = $variables['uri'];
  $wrapper = file_stream_wrapper_get_instance_by_uri($uri);
  $parts = $wrapper->get_parameters();
  $variables['video_id'] = check_plain($parts['v']);
  if (!isset($variables['player_key']) || !$variables['player_key']) {
    $variables['player_key'] = 'default';
  }
  // @see http://code.google.com/apis/youtube/player_parameters.html
  foreach (array('width', 'height', 'autoplay', 'download_link', 'fullscreen', 'download_source') as $option) {
    // Set the option, either from the options array, or from the default value.
    $variables[$option] = isset($variables[$option]) ? $variables[$option] : (isset($variables['options'][$option]) ? $variables['options'][$option] : media_kewego_variable_get($option));
  }
  
  $variables['wrapper_id'] = 'media_kewego_' . $variables['video_id'] . '_' . $variables['id'];

  $player_code = media_kewego_get_player_code($variables['video_id'], $variables['autoplay'], $variables['width'], $variables['height'], 'fr', 'kp', $variables['player_key']);
  
  $variables['output'] = $player_code;
  $download_source = $variables['download_source'];
  $path = '';
  if ($variables['download_link']) {
    $compressed_text = "Download MP4 file";
    $compressed_link = "kewego/download/" . $variables['video_id'] . "";
    $variables['output'] .= l($compressed_text, $compressed_link, array('attributes' => array('class' => array('download_link'))));
    if ($download_source) {
      $kewego = new KewegoConnection;
      $source_text = "Download source file";
      $source_link = $compressed_link . "/" . md5($variables['video_id'] . $kewego->password);
      $variables['output'] .= ' or ' . l($source_text, $source_link, array('attributes' => array('class' => array('download_link'))));
    }
  }

}

function media_kewego_get_player_code($sig, $autoplay, $width, $height, $player_key) {
  $player_code = &drupal_static(__FUNCTION__);
  if (!isset($player_code)) {
    $player_code = array();
  }
  if (!isset($player_code[$sig])) {
    if ($cache = cache_get('media_kewego_playercode_' . $sig)) {
      $player_code[$sig] = $cache->data;
    }
    else {
      $kewego = new KewegoConnection;
      $player_code[$sig] = $kewego->getPlayerCode($sig, $autoplay, $width, $height, 'fr', 'kp', $player_key);
      cache_set('media_kewego_playercode_' . $sig, (string) $player_code[$sig], 'cache');
    }
  }
  return $player_code[$sig];
}

function theme_media_kewego_field_formatter_styles($variables) {
  $element = $variables['element'];
  $style = $variables['style'];
  $variables['file'] = $element['#item'];
  $variables['uri'] = $variables['file']['uri'];
  $variables['style_name'] = $style['name'];
  return theme('media_kewego_embed', $variables);
}

/**
 * Preview for Styles UI.
 */
function theme_media_kewego_preview_style($variables) {
  $variables['uri'] = media_kewego_variable_get('preview_uri');
  $variables['field_type'] = 'file';
  $variables['object'] = file_uri_to_object($variables['uri']);

  return theme('styles', $variables);
}

/**
 * NOTE: Deprecated with Styles version 2.
 */
function theme_media_kewego_styles($variables) {
  $style = $variables['style'];
  $variables['file'] = $variables['object'];
  $variables['uri'] = $variables['object']->uri;
  $variables['style_name'] = $style['name'];
  return theme('media_kewego_embed', $variables);
}

/**
 * @todo: get this working
 *
 * This code is for embedding videos in WYSIYWG areas, not currently working.
 * NOTE: Deprecated with Styles version 2.
 */
function theme_media_kewego_embed($variables) {
  $preset_name = $variables['preset_name'];
  $preset = styles_containers_available_styles('file', 'media_kewego', $preset_name);
  $output = '';
  if (!empty($preset)) {
    // Build the URL for display.
    $uri = $variables['uri'];
    $wrapper = file_stream_wrapper_get_instance_by_uri($uri);
    $parts = $wrapper->get_parameters();

    $fullscreen_value = $autoplay = 'FALSE';
    $in_browser = $thumbnail = FALSE;

    foreach ($preset['effects'] as $effect) {
      switch ($effect['name']) {
        case 'autoplay':
          $autoplay = $effect['data']['autoplay'] ? 'TRUE' : 'FALSE';
          break;
        case 'resize':
          $width = $effect['data']['width'];
          $height = $effect['data']['height'];
          break;
        case 'fullscreen':
          $fullscreen_value = $effect['data']['fullscreen'] ? 'TRUE' : 'FALSE';
          break;
        case 'thumbnail':
          $thumbnail = $effect['data']['thumbnail'];
      }
    }
    if (isset($variables['object']->override)) {
      $override = $variables['object']->override;
      if (isset($override['width'])) {
        $width = $override['width'];
      }
      if (isset($override['height'])) {
        $height = $override['height'];
      }
      if (isset($override['wysiwyg'])) {
        $thumbnail = TRUE;
      }
      if (isset($override['browser']) && $override['browser']) {
        $in_browser = TRUE;
        $thumbnail = TRUE;
      }
    }
    $width = isset($width) ? $width : media_kewego_variable_get('width');
    $height = isset($height) ? $height : media_kewego_variable_get('height');
    $video_id = check_plain($parts['v']);
    if ($thumbnail) {
      // @todo Clean this up.
      $image_variables = array(
        'path' => $wrapper->getOriginalThumbnailPath(),
        'alt' => $variables['alt'],
        'title' => $variables['title'],
        'getsize' => FALSE,
      );
      if (isset($preset['image_style'])) {
        $image_variables['path'] = $wrapper->getLocalThumbnailPath();
        $image_variables['style_name'] = $preset['image_style'];
        $output = theme('image_style', $image_variables);
      }
      else {
        // We need to add this style attribute here so that it doesn't get lost
        // If you resize a video in a node, save it, edit it, but don't adjust
        // the sizing of the video while editing, the size will revert to the
        // default.  Adding the specific size here retains the original resizing
        $WYSIWYG = isset($variables['object']->override['style']) ? $variables['object']->override['style'] : '';
        $image_variables['attributes'] = array('width' => $width, 'height' => $height, 'style' => $WYSIWYG);
        $output = theme('image', $image_variables);
      }
      if ($in_browser) {
        // Add an overlay that says 'Kewego' to media library browser thumbnails.
        $output .= '<span />';
      }
    }
    else {
      $output = theme('media_kewego_video', array('uri' => $uri, 'width' => $width, 'height' => $height, 'autoplay' => ($autoplay == 'TRUE' ? TRUE : NULL), 'fullscreen' => ($fullscreen_value == 'TRUE' ? TRUE : NULL)));
    }
  }
  return $output;
}
